@@ -20,6 +20,11 @@
 
 #include "config.h"
 
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <pwd.h>
+
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -28,17 +33,14 @@
 #elif HAVE_SOLARIS_XINERAMA
 #include <X11/extensions/xinerama.h>
 #endif
-#include <pwd.h>
-#include <unistd.h>
-#include <syslog.h>
-
-#include <gdk/gdkx.h>
 
 #include "gdmwm.h"
 #include "gdm.h"
 #include "gdmcommon.h"
 #include "gdmconfig.h"
 
+#include "gdm-common.h"
+
 typedef struct _GdmWindow GdmWindow;
 struct _GdmWindow {
 	int x, y;
@@ -119,7 +121,7 @@ gdm_wm_screen_init (int cur_screen_num)
 
 		if (screen_num <= 0) {
 			/* should NEVER EVER happen */
-			syslog (LOG_ERR, "Xinerama active, but <= 0 screens?");
+			gdm_common_error ("Xinerama active, but <= 0 screens?");
 			gdm_wm_screen.x = 0;
 			gdm_wm_screen.y = 0;
 			gdm_wm_screen.width = gdk_screen_width ();
@@ -181,7 +183,7 @@ gdm_wm_screen_init (int cur_screen_num)
 
 		if (result <= 0) {
 			/* should NEVER EVER happen */
-			syslog (LOG_ERR, "Xinerama active, but <= 0 screens?");
+			gdm_common_error ("Xinerama active, but <= 0 screens?");
 			gdm_wm_screen.x = 0;
 			gdm_wm_screen.y = 0;
 			gdm_wm_screen.width = gdk_screen_width ();
@@ -253,12 +255,18 @@ gdm_wm_center_window (GtkWindow *cw)
  	gtk_window_move (GTK_WINDOW (cw), x, y);	
 }
 
-
+void
+gdm_wm_center_cursor (void)
+{
+    XWarpPointer (wm_disp, None, wm_root, 0, 0, 0, 0, 
+		  gdm_wm_screen.x + gdm_wm_screen.width / 2,
+		  gdm_wm_screen.y + gdm_wm_screen.height / 2);
+}
 
 static void
 trap_push (void)
 {
-	trap_depth ++;
+	trap_depth++;
 	gdk_error_trap_push ();
 }
 
@@ -321,7 +329,7 @@ get_typed_property_data (Display *xdisplay,
     }
   if (!abort && expected_format && expected_format != format_returned)
     {
-      g_warning (G_GNUC_PRETTY_FUNCTION "(): Expected format (%u) unmatched (%d), programmer was drunk?",
+      g_warning (G_GNUC_PRETTY_FUNCTION "(): Expected format (%u) unmatched (%d)",
 		 expected_format, format_returned);
       abort++;
     }
@@ -1313,7 +1321,7 @@ gdm_wm_no_login_focus_push (void)
 {
 	/* it makes not sense for this to be false then */
 	focus_new_windows = TRUE;
-	no_focus_login ++;
+	no_focus_login++;
 }
 
 void
@@ -1526,8 +1534,8 @@ gdm_wm_restore_wm_order (void)
 }
 
 void
-gdm_common_show_info_msg (const gchar *msg_file,
-			  const gchar *msg_font)
+gdm_wm_show_info_msg_dialog (const gchar *msg_file,
+			     const gchar *msg_font)
 {
 	GtkWidget *dialog, *label;
 	gchar *InfoMsg;
@@ -1573,21 +1581,47 @@ gdm_common_show_info_msg (const gchar *msg_file,
 	g_free (InfoMsg);
 }
 
+static GtkWidget *
+hig_dialog_new (GtkWindow      *parent,
+		GtkDialogFlags flags,
+		GtkMessageType type,
+		GtkButtonsType buttons,
+		const gchar    *primary_message,
+		const gchar    *secondary_message)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
+		                         GTK_DIALOG_DESTROY_WITH_PARENT,
+		                         type,
+		                         buttons,
+		                         "%s", primary_message);
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+		                                  "%s", secondary_message);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+
+  	return dialog;
+}
+
 void
-gdm_common_message (const gchar *primary_message, 
-                    const gchar *secondary_message)
+gdm_wm_message_dialog (const gchar *primary_message, 
+		       const gchar *secondary_message)
 {
 	GtkWidget *req = NULL;
 
 	/* we should be now fine for focusing new windows */
 	gdm_wm_focus_new_windows (TRUE);
 
-	req = ve_hig_dialog_new (NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_INFO,
-				 GTK_BUTTONS_OK,
-				 primary_message,
-				 secondary_message);
+	req = hig_dialog_new (NULL /* parent */,
+                              GTK_DIALOG_MODAL /* flags */,
+                              GTK_MESSAGE_INFO,
+                              GTK_BUTTONS_OK,
+                              primary_message,
+                              secondary_message);
 
 	gdm_wm_center_window (GTK_WINDOW (req));
 
@@ -1598,11 +1632,11 @@ gdm_common_message (const gchar *primary_message,
 }
 
 gint
-gdm_common_query (const gchar *primary_message,
-		  const gchar *secondary_message,
-		  const char *posbutton,
-		  const char *negbutton,
-		  gboolean has_cancel)
+gdm_wm_query_dialog (const gchar *primary_message,
+		     const gchar *secondary_message,
+		     const char *posbutton,
+		     const char *negbutton,
+		     gboolean has_cancel)
 {
 	int ret;
 	GtkWidget *req;
@@ -1611,12 +1645,12 @@ gdm_common_query (const gchar *primary_message,
 	/* we should be now fine for focusing new windows */
 	gdm_wm_focus_new_windows (TRUE);
 
-	req = ve_hig_dialog_new (NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_QUESTION,
-				 GTK_BUTTONS_NONE,
-				 primary_message,
-				 secondary_message);
+	req = hig_dialog_new (NULL /* parent */,
+                              GTK_DIALOG_MODAL /* flags */,
+                              GTK_MESSAGE_QUESTION,
+                              GTK_BUTTONS_NONE,
+                              primary_message,
+                              secondary_message);
 
 	if (negbutton != NULL) {
 		button = gtk_button_new_from_stock (negbutton);
@@ -1657,11 +1691,11 @@ gdm_common_query (const gchar *primary_message,
 }
 
 gint
-gdm_common_warn (const gchar *primary_message,
-                 const gchar *secondary_message,
-                 const char *posbutton,
-                 const char *negbutton,
-                 gboolean has_cancel)
+gdm_wm_warn_dialog (const gchar *primary_message,
+                    const gchar *secondary_message,
+                    const char *posbutton,
+                    const char *negbutton,
+                    gboolean has_cancel)
 {
 	int ret;
 	GtkWidget *req;
@@ -1670,12 +1704,12 @@ gdm_common_warn (const gchar *primary_message,
 	/* we should be now fine for focusing new windows */
 	gdm_wm_focus_new_windows (TRUE);
 
-	req = ve_hig_dialog_new (NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_WARNING,
-				 GTK_BUTTONS_NONE,
-				 primary_message,
-				 secondary_message);
+	req = hig_dialog_new (NULL /* parent */,
+                              GTK_DIALOG_MODAL /* flags */,
+                              GTK_MESSAGE_WARNING,
+                              GTK_BUTTONS_NONE,
+                              primary_message,
+                              secondary_message);
 
 	if (negbutton != NULL) {
 		button = gtk_button_new_from_stock (negbutton);
